pub struct FileInformation { /* private fields */ }Expand description
Metadata returned by get_file_information.
Implementations
Sourceimpl FileInformation
impl FileInformation
Sourcepub fn get_name(&self) -> Option<&str>
pub fn get_name(&self) -> Option<&str>
Returns file name without extension, or directory name for directories.
Sourcepub fn get_extension(&self) -> Option<&str>
pub fn get_extension(&self) -> Option<&str>
Returns file extension for files, otherwise None.
Sourcepub fn get_unix_created(&self) -> Option<&u64>
pub fn get_unix_created(&self) -> Option<&u64>
Returns created-at Unix timestamp (seconds), when available on this platform.
Sourcepub fn get_time_since_created(&self) -> Option<&u64>
pub fn get_time_since_created(&self) -> Option<&u64>
Returns age since creation in seconds, when available.
Sourcepub fn get_unix_last_opened(&self) -> Option<&u64>
pub fn get_unix_last_opened(&self) -> Option<&u64>
Returns last-accessed Unix timestamp (seconds), when available.
Sourcepub fn get_time_since_last_opened(&self) -> Option<&u64>
pub fn get_time_since_last_opened(&self) -> Option<&u64>
Returns age since last access in seconds, when available.
Sourcepub fn get_unix_last_modified(&self) -> Option<&u64>
pub fn get_unix_last_modified(&self) -> Option<&u64>
Returns last-modified Unix timestamp (seconds), when available.
Sourcepub fn get_time_since_last_modified(&self) -> Option<&u64>
pub fn get_time_since_last_modified(&self) -> Option<&u64>
Returns age since last modification in seconds, when available.